/****************************************************************************/

#include "traydebug.h"

/****************************************************************************/

// Global variable declarations
HINSTANCE hInst=NULL;
HINSTANCE hinstEditDll=NULL;
char      szAppName[50]="";
char      szTitle[120]="";
HWND      hwndMain=NULL;
HWND      hwndDebugClient=NULL;
HWND      hwndDebugEdit=NULL;

/*****************************************************************************
 * Name         - InitApplication
 * Purpose      - This function takes all of the steps neccesary to get the
 *                application up and running. By the time it has ended, the
 *                window is on the screen and ready to go.
 * Arguments    - hInstance: Instance handle of the program
 *                nCmdShow: Initial show state for the main window
 * Return Value - TRUE on success or FALSE on failure
 ****************************************************************************/
BOOL InitApplication (HINSTANCE hInstance , char * /*CmdLine*/ , int /*nCmdShow*/)
{
 CWindowClass wc (WndProc , IDS_CLASSNAME , hInstance);

 // Save the instance handle in static variable, which will be used in
 // many subsequence calls from this application to Windows.
 hInst = hInstance;

 // Load the RichEdit DLL so we can use richedit controls in our dialogs.
 hinstEditDll = LoadLibrary ("RICHED32");

 if (!hinstEditDll)
     return FALSE;

 // Load the application name and window title strings.
 CResString ClassStr (hInst , IDS_CLASSNAME , szAppName , sizeof (szAppName));
 CResString Title    (hInst , IDS_MAINCAPTION , szTitle , sizeof (szTitle));

 // The class defaults everthing based on the usual defaults and the
 // information given in the constructor. Change the things that aren't
 // set to default manually.
 wc.setStyle (CS_HREDRAW | CS_VREDRAW);
 wc.setMenu (IDM_MAINMENU);
 wc.setResIcons (IDI_MAINICON);

 // Register the window class and return FALSE if unsuccesful.
 if (!wc.registerClass ())
     return FALSE;

 // Create a main window for this application instance.
 hwndMain = CreateWindow (szAppName,           // Class name
                          Title,               // Text for window title bar
                          WS_OVERLAPPEDWINDOW, // Window style
                          CW_USEDEFAULT, 0,    // Use default positioning
                          CW_USEDEFAULT, 0,    // Use default size
                          NULL,                // Overlapped has no parent
                          NULL,                // Use the window class menu
                          hInst,               // This instance owns this window
                          NULL);               // Don't need data in WM_CREATE

 // If window could not be created, return "failure"
 if (!hwndMain)
     return FALSE;

 // Try to initialize the main window. This sets up the tray icon and creates
 // the edit client windows. If it doesn't work return failure.
 if (!InitializeMainWindow (hwndMain))
     return FALSE;

 // Make sure the window is hidden, it's never actually displayed.
 ShowWindow (hwndMain , SW_HIDE);

 return TRUE;
}

/*****************************************************************************
 * Name         - ExitApplication
 * Purpose      - This free's any globally allocated resources that are not
 *                intimately associated with a window. I.E. things that where
 *                not created when a window was created and destroyed when it
 *                was destroyed. This can be called before everything is fully
 *                initialized, so it must take care to check if a given item
 *                was initialized before cleaning it up.
 * Arguments    - None
 * Return Value - None
 ****************************************************************************/
void ExitApplication (void)
{
 if (hinstEditDll)
     FreeLibrary (hinstEditDll);
}

/****************************************************************************/

